{% for category in faq_categories %}
<h5>{{ category.title }}</h5>

<ol class="faq-nav">
{% for question in category.questions.all %}
    <li><a href="#question-{{ question.id }}">{{ question.question|safe }}</a></li>
{% endfor %}
</ol>
{% endfor %}
