{% for category in faq_categories %}
<h2>{{ category.title }}</h2>

<ol class="faq-list unstyled">
{% for question in category.questions.all %}
    <li>
        <h3 id="question-{{ question.id }}">{{ forloop.counter }}. {{ question.question|safe }}</h3>
        {{ question.answer|safe }}
    </li>
{% endfor %}
</ol>
{% endfor %}
